==> aroundme_0_3_3.zip: aroundme_0_3_3/www/aroundme_0_3_3/language/1/am_default/node_newsletter.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common_node.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//section titles
$lang['section_sent'] = 						"sent";


//HEADER
$lang['hdr_newsletter'] = 						"create your newsletter";


//SUBMIT BUTTONS
$lang['sub_newsletter'] = 						"SEND NOW!";




//BODY TEXT
$lang['txt_emails_sent'] =						"newsletters sent";
$lang['txt_subject'] =							"subject";
$lang['txt_subject_txt'] =						"Barnraiser newsletter!";
$lang['txt_subject_help'] =						"The subject of your newsletter.";
$lang['txt_message'] =							"message";
$lang['txt_message_help'] =						"Write your message in a word processor forst and ensure that you spell check it. Newsletters shoud be short and to the point with links to longer articles. The members first name will automatically be inserted into the newsletter anywhere the text 'FIRSTNAME' appears.";
$lang['txt_message_txt'] =						"Hi FIRSTNAME,\n\nMessage body here.";
$lang['txt_language'] =							"language";
$lang['txt_language_help'] =					"The newsletter will only be sent to members with the following prefered language.";
$lang['txt_to'] =								"to";
$lang['txt_to_help'] =							"send the newsletter to members, pending members (people who have registered, but not completed the setup process) or invitees (people who members have invited but have not yet registered). Please note, for invitees we do not know their language, so send a newsletter in all node languages. We do not know invitee names so do not include 'FIRSTNAME' as it will not be processed.";

$lang['txt_to_type1'] =							"members";
$lang['txt_to_type2'] =							"pending members";
$lang['txt_to_type3'] =							"invitees";
?>

==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/language/1/am_default/node_newsletter.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'node_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//section titles
$lang['section_sent'] = 						"sent";


//HEADER
$lang['hdr_newsletter'] = 						"create your newsletter";


//SUBMIT BUTTONS
$lang['sub_newsletter'] = 						"SEND NOW!";




//BODY TEXT
$lang['txt_emails_sent'] =						"newsletters sent";
$lang['txt_subject'] =							"subject";
$lang['txt_subject_txt'] =						"Barnraiser newsletter!";
$lang['txt_subject_help'] =						"The subject of your newsletter.";
$lang['txt_message'] =							"message";
$lang['txt_message_help'] =						"Write your message in a word processor forst and ensure that you spell check it. Newsletters shoud be short and to the point with links to longer articles. The members first name will automatically be inserted into the newsletter anywhere the text 'FIRSTNAME' appears.";
$lang['txt_message_txt'] =						"Hi FIRSTNAME,\n\nMessage body here.";
$lang['txt_language'] =							"language";
$lang['txt_language_help'] =					"The newsletter will only be sent to members with the following prefered language.";
$lang['txt_to'] =								"to";
$lang['txt_to_help'] =							"send the newsletter to members, pending members (people who have registered, but not completed the setup process) or invitees (people who members have invited but have not yet registered). Please note, for invitees we do not know their language, so send a newsletter in all node languages. We do not know invitee names so do not include 'FIRSTNAME' as it will not be processed.";

$lang['txt_to_type1'] =							"members";
$lang['txt_to_type2'] =							"pending members";
$lang['txt_to_type3'] =							"invitees";
?>
